import './App.css';
import React from 'react';
import { BrowserRouter, Routes, Route, NavLink } from 'react-router-dom';

import OnlineToggle from './components/OnlineToggle';
import Wobler from './components/Wobler';

import About from "./components/About"
import Games from './container/Games';
import Leaderboard from './container/Leaderboard';

import usePollingReducer from './reducer/polling';
import useGamesReducer from './reducer/games';

import useUserApi from './api/user';
import useLeaderboardApi from './api/leaderboard';
import useGamesApi from './api/games';

export default function App() {
  const pollingReducer = usePollingReducer();

  const leaderboard = useLeaderboardApi().poll(pollingReducer);
  const user = useUserApi().get();

  const [games, dispatchGames] = useGamesReducer();
  const gamesApi = useGamesApi(dispatchGames);
  gamesApi.list(pollingReducer);

  const players = {
    leaderboard,
    isCurrentUser: (playerName) => user?.isCurrentUser(playerName) === true ? true : null
  };

  return (
    <BrowserRouter>
      <Header pollingReducer={pollingReducer} />
      <Routes>
        <Route path='/' element={<About />} />
        <Route path='/about' element={<About />} />
        <Route path='/games/*' element={<Games context={{ games, dispatchGames, gamesApi }} players={players} />} />
        <Route path='/leaderboard' element={<Leaderboard players={players} />} />
      </Routes>
    </BrowserRouter>
  )
}

function Header({ pollingReducer }) {
  const [polling, dispatchPolling] = pollingReducer;

  return (
    <div className='Header'>
      <h1>
        CordaCheckers
      </h1>

      <OnlineToggle
        isOnline={polling.enabled}
        onClick={() => dispatchPolling({ type: 'toggleOnOff' })}
      />

      <nav>
        <NavLink to='/about'>
          About
        </NavLink>

        <NavLink to='/games'>
          <Wobler text="Games" dance={polling.games} />
        </NavLink>

        <NavLink to='/leaderboard'>
          <Wobler text='Leaderboard' dance={polling.leaderboard} />
        </NavLink>
      </nav>
    </div>
  )
}